@@ -9,5 +9,5 @@
 (*                                                                     *)
 (***********************************************************************)
 
-val getenv : string -> string;;
+val get_env : string -> string;;
 val main : unit -> unit;;
