@@ -9,14 +9,14 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: substitute.mli,v 1.1 2003/03/02 18:28:54 weis Exp $ *)
+(* $Id: substitute.mli,v 1.2 2003/10/01 17:06:00 weis Exp $ *)
 
 
 (* Variable substitution in buffers:
    Substitute $ident (or $(ident)) in a string are substituted
    according to an environment that maps the variables to strings. *)
 
-val add_string :
+val add_string_substitute :
  (string, string) Hashtbl.t -> Buffer.t -> string -> unit;;
 
 (** [add_string_substitute t b s] Add string [s] to buffer [b], after
@@ -29,3 +29,7 @@ val add_string :
     Variables of the form [<$ident>] are substituted by their value in
     the user's environment (using the standard [Sys.getenv]
     function). *)
+
+val add_string :
+ (string -> string) -> Buffer.t -> string -> unit;;
+(** Same as above with a general substitution function. *)
