@@ -9,8 +9,23 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: version.ml,v 1.5 2003/09/18 15:25:02 weis Exp $ *)
+(* $Id: version.ml,v 1.12 2004/09/01 08:12:25 weis Exp $ *)
 
-let version = "1.30";;
+(* The current version of htmlc *)
+let htmlc_version_number = 1.6;;
+let htmlc_sub_version_number = 0;;
+let htmlc_version_date = "2004-09-01";;
+
+let htmlc_version =
+  Printf.sprintf "%.2f" htmlc_version_number;;
+
+let htmlc_full_version =
+  Printf.sprintf "%.2f+%i (%s)"
+    htmlc_version_number htmlc_sub_version_number htmlc_version_date;;
+
+let print_version () =
+  prerr_endline ("htmlc, version " ^ htmlc_version);;
+
+let print_full_version () =
+  prerr_endline ("htmlc, version " ^ htmlc_full_version);;
 
-let current = version;;
